@@ -77,6 +77,37 @@ qmesh3d <- function( vertices, indices, homogeneous=TRUE, material=NULL, normals
   return( object )
 }
 
+as.mesh3d <- function(x, ...) UseMethod("as.mesh3d")
+
+as.mesh3d.deldir <- function(x, col = "gray", coords = c("x", "y", "z"), 
+			     smooth = TRUE, normals = NULL, texcoords = NULL,
+			     ...) {
+  if (!requireNamespace("deldir"))
+    stop("The ", sQuote("deldir"), " package is required.")
+  if (!identical(sort(coords), c("x", "y", "z")))
+    stop(sQuote("coords"), " should be a permutation of c('x', 'y', 'z')")
+  if (!all(coords %in% names(x$summary)))
+    stop("The 'deldir' object needs x, y, and z coordinates.")
+  if (smooth && !is.null(normals)) {
+    warning("'smooth' ignored as 'normals' was specified.")
+    smooth <- FALSE
+  }
+  points <- t(as.matrix(x$summary[, coords]))
+  triangs <- do.call(rbind, deldir::triang.list(x))
+  if (length(col) > 1) {
+    col <- rep_len(col, ncol(points))
+    col <- col[triangs$ptNum]
+  }
+  if (!is.null(texcoords))
+    texcoords <- texcoords[triangs$ptNum, ]
+  result <- tmesh3d(points, triangs$ptNum, homogeneous = FALSE,
+  	  normals = normals, texcoords = texcoords,
+  	  material = list(col = col, ...))
+  if (smooth)
+    result <- addNormals(result)
+  result
+}
+
 # rendering support
 
 dot3d.mesh3d <- function ( x, override = TRUE, ... ) {
@@ -88,10 +119,10 @@ dot3d.mesh3d <- function ( x, override = TRUE, ... ) {
     material <- list(...)
     material[names(x$material)] <- x$material
   }
-  
-  do.call("points3d", args = c(list(x = x$vb[1,]/x$vb[4,], 
-                                    y = x$vb[2,]/x$vb[4,], 
-                                    z = x$vb[3,]/x$vb[4,]), 
+  ind <- unique(c(x$it, x$ib))
+  do.call("points3d", args = c(list(x = x$vb[1,ind]/x$vb[4,ind], 
+                                    y = x$vb[2,ind]/x$vb[4,ind], 
+                                    z = x$vb[3,ind]/x$vb[4,ind]), 
                                material ))
 }     
 
@@ -106,21 +137,18 @@ wire3d.mesh3d <- function ( x, override = TRUE, ... ) {
     material <- list(...)
     material[names(x$material)] <- x$material
   }
-  material["front"] <- "lines"
-  material["back"] <- "lines"
-  
-  result <- integer(0)
+  ind <- integer(0)
   if (!is.null(x$it))
-    result <- c(triangles = do.call("triangles3d", args = c(list(x = x$vb[1,x$it]/x$vb[4,x$it],
-                                         y = x$vb[2,x$it]/x$vb[4,x$it],
-                                         z = x$vb[3,x$it]/x$vb[4,x$it]), 
-                                    material)))
+    ind <- c(rbind(x$it, x$it[1,], NA))
   if (!is.null(x$ib))
-    result <- c(result, quads = do.call("quads3d", args = c(list(x = x$vb[1,x$ib]/x$vb[4,x$ib],
-                                     y = x$vb[2,x$ib]/x$vb[4,x$ib],
-                                     z = x$vb[3,x$ib]/x$vb[4,x$ib]), 
-                                material)))
-  invisible(result)
+    ind <- c(ind, rbind(x$ib, x$ib[1,], NA))
+  # Remove duplicate edges?
+  if (length(ind))
+    ind <- ind[-length(ind)]
+  do.call("lines3d", args =  c(list(x = x$vb[1,ind]/x$vb[4,ind], 
+                                    y = x$vb[2,ind]/x$vb[4,ind], 
+                                    z = x$vb[3,ind]/x$vb[4,ind]), 
+                               material ))
 }
 
 shade3d.mesh3d <- function ( x, override = TRUE, ... ) {
@@ -158,7 +186,7 @@ shade3d.mesh3d <- function ( x, override = TRUE, ... ) {
     
     result <- c(result, quads = do.call("quads3d", args = args ))
   }
-  invisible(result)
+  lowlevel(result)
 }
 
 # transformation support
@@ -198,3 +226,17 @@ translate3d.qmesh3d <- translate3d.mesh3d
 rotate3d.qmesh3d <- rotate3d.mesh3d
 scale3d.qmesh3d <- scale3d.mesh3d
 
+# for debugging
+showNormals <- function(obj, scale = 1) {
+  v <- obj$vb
+  n <- obj$normals
+  if (is.null(n)) {
+    warning("No normals found.")
+    return()
+  }
+  for (i in seq_len(ncol(n))) {
+    p0 <- v[1:3, i]/v[4, i]
+    p1 <- p0 + n[1:3, i]*scale
+    arrow3d(p0, p1, type = "lines")
+  }
+}
